@@ -1,7 +1,7 @@
 <?php
 namespace TYPO3\CMS\Core\Resource\Exception;
 
-/**
+/*
  * This file is part of the TYPO3 CMS project.
  *
  * It is free software; you can redistribute it and/or modify it under
@@ -13,11 +13,11 @@ namespace TYPO3\CMS\Core\Resource\Exception;
  *
  * The TYPO3 project - inspiring people to share!
  */
+
 /**
  * An exception when something is wrong with the file handling
  *
  */
-class IllegalFileExtensionException extends \TYPO3\CMS\Core\Resource\Exception {
-
-
+class IllegalFileExtensionException extends \TYPO3\CMS\Core\Resource\Exception
+{
 }
