@@ -1,7 +1,7 @@
 <?php
 namespace TYPO3\CMS\Core\Resource\Processing;
 
-/**
+/*
  * This file is part of the TYPO3 CMS project.
  *
  * It is free software; you can redistribute it and/or modify it under
@@ -17,21 +17,21 @@ namespace TYPO3\CMS\Core\Resource\Processing;
 /**
  * Interface for file processors. All classes capable of processing a file have to implement this interface.
  */
-interface ProcessorInterface {
+interface ProcessorInterface
+{
+    /**
+     * Returns TRUE if this processor can process the given task.
+     *
+     * @param TaskInterface $task
+     * @return bool
+     */
+    public function canProcessTask(TaskInterface $task);
 
-	/**
-	 * Returns TRUE if this processor can process the given task.
-	 *
-	 * @param TaskInterface $task
-	 * @return boolean
-	 */
-	public function canProcessTask(TaskInterface $task);
-
-	/**
-	 * Processes the given task and sets the processing result in the task object.
-	 *
-	 * @param TaskInterface $task
-	 * @return void
-	 */
-	public function processTask(TaskInterface $task);
+    /**
+     * Processes the given task and sets the processing result in the task object.
+     *
+     * @param TaskInterface $task
+     * @return void
+     */
+    public function processTask(TaskInterface $task);
 }
