@@ -1,7 +1,7 @@
 <?php
 namespace TYPO3\CMS\Core\Tests\Unit\Log\Fixtures;
 
-/**
+/*
  * This file is part of the TYPO3 CMS project.
  *
  * It is free software; you can redistribute it and/or modify it under
@@ -16,19 +16,17 @@ namespace TYPO3\CMS\Core\Tests\Unit\Log\Fixtures;
 
 /**
  * A processor dedicated for testing
- *
- * @author Steffen Müller <typo3@t3node.com>
  */
-class ProcessorFixture extends \TYPO3\CMS\Core\Log\Processor\AbstractProcessor {
-
-	/**
-	 * Processing the record
-	 *
-	 * @param \TYPO3\CMS\Core\Log\LogRecord $record
-	 * @return \TYPO3\CMS\Core\Log\LogRecord
-	 */
-	public function processLogRecord(\TYPO3\CMS\Core\Log\LogRecord $record) {
-		return $record;
-	}
-
+class ProcessorFixture extends \TYPO3\CMS\Core\Log\Processor\AbstractProcessor
+{
+    /**
+     * Processing the record
+     *
+     * @param \TYPO3\CMS\Core\Log\LogRecord $record
+     * @return \TYPO3\CMS\Core\Log\LogRecord
+     */
+    public function processLogRecord(\TYPO3\CMS\Core\Log\LogRecord $record)
+    {
+        return $record;
+    }
 }
