@@ -1,7 +1,7 @@
 <?php
 namespace TYPO3\CMS\Extbase\Persistence;
 
-/**
+/*
  * This file is part of the TYPO3 CMS project.
  *
  * It is free software; you can redistribute it and/or modify it under
@@ -13,26 +13,27 @@ namespace TYPO3\CMS\Extbase\Persistence;
  *
  * The TYPO3 project - inspiring people to share!
  */
+
 /**
  * An interface how to monitor changes on an object and its properties. All domain objects which should be persisted need to implement the below interface.
  *
  * @see \TYPO3\CMS\Extbase\DomainObject\AbstractEntity
  * @see \TYPO3\CMS\Extbase\DomainObject\AbstractValueObject
  */
-interface ObjectMonitoringInterface {
+interface ObjectMonitoringInterface
+{
+    /**
+     * Register an object's clean state, e.g. after it has been reconstituted
+     * from the database
+     *
+     * @return void
+     */
+    public function _memorizeCleanState();
 
-	/**
-	 * Register an object's clean state, e.g. after it has been reconstituted
-	 * from the database
-	 *
-	 * @return void
-	 */
-	public function _memorizeCleanState();
-
-	/**
-	 * Returns TRUE if the properties were modified after reconstitution
-	 *
-	 * @return boolean
-	 */
-	public function _isDirty();
+    /**
+     * Returns TRUE if the properties were modified after reconstitution
+     *
+     * @return bool
+     */
+    public function _isDirty();
 }
