@@ -1,7 +1,8 @@
 <?php
+namespace TYPO3\CMS\Fluid\Core;
 
 /*                                                                        *
- * This script is backported from the FLOW3 package "TYPO3.Fluid".        *
+ * This script is backported from the TYPO3 Flow package "TYPO3.Fluid".   *
  *                                                                        *
  * It is free software; you can redistribute it and/or modify it under    *
  * the terms of the GNU Lesser General Public License, either version 3   *
@@ -9,13 +10,11 @@
  *                                                                        *
  * The TYPO3 project - inspiring people to share!                         *
  *                                                                        */
-
 /**
  * A generic Fluid Core exception.
  *
  * @api
  */
-class Tx_Fluid_Core_Exception extends Tx_Fluid_Exception {
+class Exception extends \TYPO3\CMS\Fluid\Exception
+{
 }
-
-?>
\ No newline at end of file
