@@ -1,7 +1,8 @@
 <?php
+namespace TYPO3\CMS\Fluid\Core\ViewHelper;
 
 /*                                                                        *
- * This script is backported from the FLOW3 package "TYPO3.Fluid".        *
+ * This script is backported from the TYPO3 Flow package "TYPO3.Fluid".   *
  *                                                                        *
  * It is free software; you can redistribute it and/or modify it under    *
  * the terms of the GNU Lesser General Public License, either version 3   *
@@ -9,12 +10,11 @@
  *                                                                        *
  * The TYPO3 project - inspiring people to share!                         *
  *                                                                        */
-
 /**
  * A ViewHelper Exception
  *
  * @api
  */
-class Tx_Fluid_Core_ViewHelper_Exception extends Tx_Fluid_Core_Exception {
+class Exception extends \TYPO3\CMS\Fluid\Core\Exception
+{
 }
-?>
