@@ -1,7 +1,8 @@
 <?php
+namespace TYPO3\CMS\Fluid\Tests\Unit\ViewHelpers\Form\Fixtures;
 
 /*                                                                        *
- * This script is backported from the FLOW3 package "TYPO3.Fluid".        *
+ * This script is backported from the TYPO3 Flow package "TYPO3.Fluid".   *
  *                                                                        *
  * It is free software; you can redistribute it and/or modify it under    *
  * the terms of the GNU Lesser General Public License, either version 3   *
@@ -12,15 +13,10 @@
 
 /**
  * [Enter description here]
- *
  */
-class Tx_Fluid_ViewHelpers_Fixtures_EmptySyntaxTreeNode extends Tx_Fluid_Core_Parser_SyntaxTree_ViewHelperNode {
-	
-	public function __construct() {
-		
-	}
-	
+class EmptySyntaxTreeNode extends \TYPO3\CMS\Fluid\Core\Parser\SyntaxTree\ViewHelperNode
+{
+    public function __construct()
+    {
+    }
 }
-
-
-?>
