@@ -20,32 +20,37 @@ namespace TYPO3\CMS\Fluid\Tests\Unit\ViewHelpers\Uri;
  *                                                                        *
  * The TYPO3 project - inspiring people to share!                         *
  *                                                                        */
+use TYPO3\CMS\Fluid\Tests\Unit\ViewHelpers\ViewHelperBaseTestcase;
+use TYPO3\CMS\Fluid\ViewHelpers\Uri\EmailViewHelper;
+use TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer;
 
 /**
  * Testcase for the email uri view helper
  */
-class EmailViewHelperTest extends \TYPO3\CMS\Fluid\Tests\Unit\ViewHelpers\ViewHelperBaseTestcase {
+class EmailViewHelperTest extends ViewHelperBaseTestcase
+{
+    /**
+     * @var \TYPO3\CMS\Fluid\ViewHelpers\Uri\EmailViewHelper
+     */
+    protected $viewHelper;
 
-	/**
-	 * @var \TYPO3\CMS\Fluid\ViewHelpers\Uri\EmailViewHelper
-	 */
-	protected $viewHelper;
+    protected function setUp()
+    {
+        parent::setUp();
+        $GLOBALS['TSFE'] = new \stdClass();
+        $GLOBALS['TSFE']->cObj = $this->getMock(ContentObjectRenderer::class, [], [], '', false);
+        $this->viewHelper = new EmailViewHelper();
+        $this->injectDependenciesIntoViewHelper($this->viewHelper);
+        $this->viewHelper->initializeArguments();
+    }
 
-	public function setUp() {
-		parent::setUp();
-		$GLOBALS['TSFE'] = new \stdClass();
-		$GLOBALS['TSFE']->cObj = $this->getMock('TYPO3\\CMS\\Frontend\\ContentObject\\ContentObjectRenderer', array(), array(), '', FALSE);
-		$this->viewHelper = new \TYPO3\CMS\Fluid\ViewHelpers\Uri\EmailViewHelper();
-		$this->injectDependenciesIntoViewHelper($this->viewHelper);
-		$this->viewHelper->initializeArguments();
-	}
-
-	/**
-	 * @test
-	 */
-	public function renderReturnsFirstResultOfGetMailTo() {
-		$this->viewHelper->initialize();
-		$actualResult = $this->viewHelper->render('some@email.tld');
-		$this->assertEquals('mailto:some@email.tld', $actualResult);
-	}
+    /**
+     * @test
+     */
+    public function renderReturnsFirstResultOfGetMailTo()
+    {
+        $this->viewHelper->initialize();
+        $actualResult = $this->viewHelper->render('some@email.tld');
+        $this->assertEquals('mailto:some@email.tld', $actualResult);
+    }
 }
